%MAKEGAUSSIANKERNEL generates a 1-dimensional Gaussian kernel
%
%  kernel = makeGaussianKernel(kSize, sigma) generates a 1-dimensional
%  Gaussian kernel of size kSize with standard deviation of sigma
%
%  Inputs:
%    1) kSize: Size of the returned kernel
%    2) sigma: Standard deviation of the returned kernel
%  Outputs:
%    1) kernel: A Gaussian kernel of size kSize with standard deviation of sigma

function kernel = makeGaussianKernel(kSize, sigma)
kernel = zeros(1,kSize);
for i=1:kSize
    kernel(i) = 1/sqrt(2*pi*sigma^2) * exp(-(i-ceil(kSize/2))^2/(2*sigma^2));
end
kernel = kernel/sum(kernel);
